@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `acpi` command output parser
+"""jc - JSON Convert `acpi` command output parser
 
 Usage (cli):
 
