@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `date` command output parser
+"""jc - JSON Convert `date` command output parser
 
 The `epoch` calculated timestamp field is naive. (i.e. based on the local
 time of the system the parser is run on)
