@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `df` command output parser
+"""jc - JSON Convert `df` command output parser
 
 Usage (cli):
 
