@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `id` command output parser
+"""jc - JSON Convert `id` command output parser
 
 Usage (cli):
 
