@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `iptables` command output parser
+"""jc - JSON Convert `iptables` command output parser
 
 Supports `-vLn` and `--line-numbers` for all tables.
 
