@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `last` and `lastb` command output parser
+"""jc - JSON Convert `last` and `lastb` command output parser
 
 Supports `-w` and `-F` options.
 
