@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `pip-show` command output parser
+"""jc - JSON Convert `pip-show` command output parser
 
 Usage (cli):
 
