@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `ps` command output parser
+"""jc - JSON Convert `ps` command output parser
 
 `ps` options supported:
 - `ef`
