@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `sfdisk` command output parser
+"""jc - JSON Convert `sfdisk` command output parser
 
 Supports the following `sfdisk` options:
 - `-l`
