@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `systemctl list-jobs` command output parser
+"""jc - JSON Convert `systemctl list-jobs` command output parser
 
 Usage (cli):
 
