@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `traceroute` command output parser
+"""jc - JSON Convert `traceroute` command output parser
 
 Supports `traceroute` and `traceroute6` output.
 
