@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `upower` command output parser
+"""jc - JSON Convert `upower` command output parser
 
 The `updated_epoch` calculated timestamp field is naive. (i.e. based on the
 local time of the system the parser is run on)
