@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `vmstat` command output parser
+"""jc - JSON Convert `vmstat` command output parser
 
 Options supported: `-a`, `-w`, `-d`, `-t`
 
